@@ -17,18 +17,12 @@ except PackageNotFoundError:
 
 import di.api as api  # noqa: E402
 from di.container import BaseContainer, Container  # noqa: E402
-from di.dependant import (  # noqa: E402
-    CallableClassDependant,
-    Dependant,
-    JoinedDependant,
-)
+from di.dependant import Dependant, JoinedDependant  # noqa: E402
 from di.executors import (  # noqa: E402
+    AsyncExecutor,
     ConcurrentAsyncExecutor,
-    DefaultExecutor,
-    SimpleAsyncExecutor,
-    SimpleSyncExecutor,
+    SyncExecutor,
 )
-from di.params import Depends  # noqa: E402
 
 __all__ = (
     "api",
@@ -36,10 +30,7 @@ __all__ = (
     "Container",
     "Dependant",
     "JoinedDependant",
-    "CallableClassDependant",
-    "Depends",
-    "DefaultExecutor",
     "ConcurrentAsyncExecutor",
-    "SimpleAsyncExecutor",
-    "SimpleSyncExecutor",
+    "AsyncExecutor",
+    "SyncExecutor",
 )
